@@ -51,12 +51,24 @@ get_modelmatrix.bracl <- function(x, ...) {
   mm
 }
 
+#' @export
+get_modelmatrix.serp <- function(x, ...) {
+  dots <- list(...)
+  if ("data" %in% names(dots)) {
+    mm <- stats::model.matrix(object = x$Terms, data = dots$data, ...)
+  } else {
+    mm <- stats::model.matrix(object = x$Terms, data = get_data(x), ...)
+  }
+
+  mm
+}
+
 #' @export
 get_modelmatrix.iv_robust <- function(x, ...) {
   dots <- list(...)
   model_terms <- stats::terms(x)
   if ("data" %in% names(dots)) {
-    # sanity check - model matrix needs response vector!
+    # validation check - model matrix needs response vector!
     resp <- find_response(x)
     d <- dots$data
     dots$data <- NULL
@@ -76,7 +88,7 @@ get_modelmatrix.iv_robust <- function(x, ...) {
 get_modelmatrix.lm_robust <- function(x, ...) {
   dots <- list(...)
   if ("data" %in% names(dots)) {
-    # sanity check - model matrix needs response vector!
+    # validation check - model matrix needs response vector!
     resp <- find_response(x)
     d <- dots$data
     dots$data <- NULL
@@ -118,7 +130,7 @@ get_modelmatrix.clmm <- function(x, ...) {
 get_modelmatrix.svyglm <- function(x, ...) {
   dots <- list(...)
   if ("data" %in% names(dots)) {
-    data <- tryCatch(
+    model_data <- tryCatch(
       {
         d <- as.data.frame(dots$data)
         response_name <- find_response(x)
@@ -135,7 +147,7 @@ get_modelmatrix.svyglm <- function(x, ...) {
       }
     )
     model_terms <- stats::terms(x)
-    mm <- stats::model.matrix(model_terms, data = data)
+    mm <- stats::model.matrix(model_terms, data = model_data)
   } else {
     mm <- stats::model.matrix(object = x, ...)
   }
@@ -171,7 +183,7 @@ get_modelmatrix.rlm <- function(x, ...) {
     data = mf,
     contrasts.arg = x$contrasts
   )
-  return(mm)
+  mm
 }
 
 
@@ -191,7 +203,7 @@ get_modelmatrix.betareg <- function(x, ...) {
     ))
     mm <- stats::model.matrix(stats::delete.response(x$terms$mean), mf)
   }
-  return(mm)
+  mm
 }
 
 
@@ -220,7 +232,7 @@ get_modelmatrix.BFBayesFactor <- function(x, ...) {
 
 
 .data_in_dots <- function(..., object = NULL, default_data = NULL) {
-  dot.arguments <- lapply(match.call(expand.dots = FALSE)$`...`, function(x) x)
+  dot.arguments <- lapply(match.call(expand.dots = FALSE)[["..."]], function(x) x)
   data_arg <- if ("data" %in% names(dot.arguments)) {
     eval(dot.arguments[["data"]])
   } else {
@@ -259,7 +271,7 @@ get_modelmatrix.BFBayesFactor <- function(x, ...) {
   out <- rbind(pad, data)
   row.names(out) <- NULL
   attr(out, "pad") <- nrow(pad)
-  return(out)
+  out
 }
 
 
